@@ -5,17 +5,15 @@
 """
 Main module of python-gvm.
 """
+
 from .__version__ import __version__
 
 
 def get_version() -> str:
-    """Returns the version of python-gvm as a string in `PEP440`_ compliant
-    format.
+    """Returns the version of python-gvm as a string in
+    `PEP440 <https://www.python.org/dev/peps/pep-0440>`_ compliant format.
 
     Returns:
         Current version of python-gvm
-
-    .. _PEP440:
-       https://www.python.org/dev/peps/pep-0440
     """
     return __version__
