@@ -15,17 +15,17 @@ from .._protocol import GvmProtocol, T, str_transform
 from ._gmp224 import GMPv224
 from ._gmp225 import GMPv225
 from ._gmp226 import GMPv226
+from ._gmp227 import GMPv227
 from .requests import Version
 
-SUPPORTED_GMP_VERSIONS = Union[GMPv224[T], GMPv225[T], GMPv226[T]]
-_SUPPORTED_GMP_VERSION_STRINGS = ["22.4", "22.5", "22.6"]
+SUPPORTED_GMP_VERSIONS = Union[GMPv224[T], GMPv225[T], GMPv226[T], GMPv227[T]]
+_SUPPORTED_GMP_VERSION_STRINGS = ["22.4", "22.5", "22.6", "22.7"]
 
 
 class GMP(GvmProtocol[T]):
     """Dynamically select supported GMP protocol of the remote manager daemon.
 
-    Must be used as a `Context Manager
-    <https://docs.python.org/3/reference/datamodel.html#context-managers>`_
+    Must be used as a `Context Manager <https://docs.python.org/3/reference/datamodel.html#context-managers>`_
 
     Example:
 
@@ -36,11 +36,11 @@ class GMP(GvmProtocol[T]):
             with GMP(connection) as gmp:
                 # gmp can be an instance of
                 # gvm.protocols.gmp.GMPv224,
-                # gvm.protocols.gmp.GMPv225
-                # or gvm.protocols.gmp.GMPv226
+                # gvm.protocols.gmp.GMPv225,
+                # gvm.protocols.gmp.GMPv226,
+                # or gvm.protocols.gmp.GMPv227
                 # depending on the supported GMP version of the remote manager daemon
                 resp = gmp.get_tasks()
-
     """
 
     def __init__(
@@ -55,15 +55,12 @@ class GMP(GvmProtocol[T]):
         Args:
             connection: Connection to use to talk with the remote daemon. See
                 :mod:`gvm.connections` for possible connection types.
-            transform: Optional transform `callable`_ to convert response data.
-                After each request the callable gets passed the plain response data
+            transform: Optional transform `callable <https://docs.python.org/3/library/functions.html#callable>`_
+                to convert response data. After each request the callable gets passed the plain response data
                 which can be used to check the data and/or conversion into different
                 representations like a xml dom.
 
                 See :mod:`gvm.transforms` for existing transforms.
-
-        .. _callable:
-            https://docs.python.org/3/library/functions.html#callable
         """
         super().__init__(connection, transform=transform)
         self._gmp: Optional[SUPPORTED_GMP_VERSIONS] = None
@@ -98,7 +95,7 @@ class GMP(GvmProtocol[T]):
             gmp_class = GMPv226
             if minor_version > 6:
                 warnings.warn(
-                    "Remote manager daemon uses a newer GMP version then "
+                    "Remote manager daemon uses a newer GMP version than "
                     f"supported by python-gvm {__version__}. Please update to "
                     "a newer release of python-gvm if possible. "
                     f"Remote GMP version is {major_version}.{minor_version}. "
