@@ -6,7 +6,7 @@
 import unittest
 
 from gvm.errors import InvalidArgument
-from gvm.protocols.gmpv224 import EntityType
+from gvm.protocols.gmp.requests.v224 import EntityType
 
 
 class GetEntityTypeFromStringTestCase(unittest.TestCase):
