@@ -4,8 +4,8 @@
 #
 
 from ...gmpv224.system.aggregates import GmpGetAggregatesTestMixin
-from ...gmpv225 import Gmpv225TestCase
+from ...gmpv225 import GMPTestCase
 
 
-class Gmpv225GetAggregatesTestCase(GmpGetAggregatesTestMixin, Gmpv225TestCase):
+class Gmpv225GetAggregatesTestCase(GmpGetAggregatesTestMixin, GMPTestCase):
     pass
