@@ -18,7 +18,7 @@ class OSPGetScannerDetailsTestCase(unittest.TestCase):
     def test_get_scanner_details_with_params(self):
         self.osp.get_scanner_details()
 
-        self.connection.send.has_been_called_with("<get_scanner_details/>")
+        self.connection.send.has_been_called_with(b"<get_scanner_details/>")
 
 
 if __name__ == "__main__":
