@@ -16,7 +16,7 @@ class EtreeCheckCommandTransformTestCase(unittest.TestCase):
         transform = EtreeCheckCommandTransform()
 
         with self.assertRaises(GvmError):
-            transform("<foo/>")
+            transform(b"<foo/>")
 
     def test_no_success_status_transform(self):
         transform = EtreeCheckCommandTransform()
@@ -25,7 +25,7 @@ class EtreeCheckCommandTransformTestCase(unittest.TestCase):
         root.set("status", "400")
         root.set("status_text", "Foo error")
 
-        response = etree.tostring(root).decode("utf-8")
+        response = etree.tostring(root)
 
         with self.assertRaises(GvmError):
             transform(response)
@@ -36,7 +36,7 @@ class EtreeCheckCommandTransformTestCase(unittest.TestCase):
         root = etree.Element("foo_response")
         root.set("status", "200")
 
-        response = etree.tostring(root).decode("utf-8")
+        response = etree.tostring(root)
 
         result = transform(response)
 
